package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.LcdInfoUserRelationMapper;
import com.ruoyi.system.domain.LcdInfoUserRelation;
import com.ruoyi.system.service.ILcdInfoUserRelationService;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2023-01-16
 */
@Service
public class LcdInfoUserRelationServiceImpl implements ILcdInfoUserRelationService
{
    @Autowired
    private LcdInfoUserRelationMapper lcdInfoUserRelationMapper;

    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public LcdInfoUserRelation selectLcdInfoUserRelationById(Long id)
    {
        return lcdInfoUserRelationMapper.selectLcdInfoUserRelationById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param lcdInfoUserRelation 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<LcdInfoUserRelation> selectLcdInfoUserRelationList(LcdInfoUserRelation lcdInfoUserRelation)
    {
        return lcdInfoUserRelationMapper.selectLcdInfoUserRelationList(lcdInfoUserRelation);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param lcdInfoUserRelation 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertLcdInfoUserRelation(LcdInfoUserRelation lcdInfoUserRelation)
    {
        return lcdInfoUserRelationMapper.insertLcdInfoUserRelation(lcdInfoUserRelation);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param lcdInfoUserRelation 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateLcdInfoUserRelation(LcdInfoUserRelation lcdInfoUserRelation)
    {
        return lcdInfoUserRelationMapper.updateLcdInfoUserRelation(lcdInfoUserRelation);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteLcdInfoUserRelationByIds(Long[] ids)
    {
        return lcdInfoUserRelationMapper.deleteLcdInfoUserRelationByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteLcdInfoUserRelationById(Long id)
    {
        return lcdInfoUserRelationMapper.deleteLcdInfoUserRelationById(id);
    }
}
